Duplicate data frame for each treatment arm to emulate
clone_arms(data, arms)Input data frame that contains all observations of interest. Each row represents an observation, and columns include observation identifiers, binary treatment variable (0/1), time to treatement (continuous), binary outcome variable (0/1), observed followup time (continuous), and covariates.
Character vector that each element represents each arm's name.
A list of data frame. Each element of list is associated with each arm.